#!/usr/local/bin/php
<?php
/*
	Tool used to search for and display wordpress databases containing user id > 1000000 
	Also, it will display if MailPoet has been installed on website.
	
	Version: 0.2
	Author: Artefact.io

	DISCLAIMER
	This program is provided as is and with no warranty of any kind. Use at your own risk.
	
	History
	Version: 0.2 added MailPoet check, MySQL host and port, minor code changes
*/
$USAGE='
wphunt 0.2 from artefact.io

  Usage
  ./wphunt.php -cnf <path to .my.cnf> [-host <mysql hostname>] [-port <mysql port>] [-debug]
';
error_reporting(0);

// Input
if (($args=parse_cli_args())===false) exit("CLI mode only\n");

$host= (isset($args['host'])) ? $args['host'] : 'localhost';
$port= (isset($args['port'])) ? $args['port'] : '3306';
$debug= (isset($args['debug'])) ? true : false;

// Debug
if ($debug) error_reporting(E_ALL);

// Load configuration or display usage
if (isset($args['cnf'])) {

	if (($tmp=parse_ini_file($args['cnf']))===false) exit("Can't load $args[cnf]\n");

	$user=$tmp['user'];
	$pass=$tmp['password'];
	echo "Using username '$user' to connect to $host:$port\n";

} else {

	exit("$USAGE\n");
	
}

// Connect
mysql_connect("$host:$port", $user, $pass) or exit("Connect error\n");

// List databases
$databases=array();
$q=mysql_query('SHOW DATABASES') or exit("\nERROR *** ".mysql_error()."\n");
while ($r=mysql_fetch_row($q)) $databases[]=$r[0];

if (empty($databases)) exit("No databases\n");
echo "Found ".count($databases)." databases\n";

foreach ($databases as $database) {
	
	// Get tables; I'm using reversed key-value array for speed
	$tables=array();
	$q=mysql_query('SHOW TABLES FROM `'.$database.'` LIKE "wp%"') or exit("\nERROR *** ".mysql_error()."\n");
	while ($r=mysql_fetch_row($q)) $tables[$r[0]]=true;
	
	if (empty($tables)) continue; // skip if empty
	
	if (!isset($tables['wp_users'])) continue; // skip if wp_users does not exists
		
	// Get highest ID from wp_users table
	$q=mysql_query('SELECT MAX(ID) FROM `'.$database.'`.`wp_users`') or exit("\nERROR *** ".mysql_error()."\n");
	$r=mysql_fetch_row($q);

	// Do checks
	$hit=false;
	
	$out=sprintf('%-25s', $database)."\t";
	
	if ($r[0] > 1000000) {
		$out.=sprintf('%-20s', 'Hacked? ID '.$r[0])."\t";
		$hit=true;
	} else {
		$out.=sprintf('%-20s', 'OK')."\t";
	}
	
	if (isset($tables['wp_wysija_list'])) {
		$out.="MailPoet detected\t";
		$hit=true;
	}

	if ($hit) echo "$out\n";
}


/*
	Parse CLI args 1.0

  Windows: php -f script.php -- <args>
  Linux:   ./script.php <args>

	example args:
		-key1 value1 -key2 value2 unnamed1 unnamed2

	return array
	_cmd 			script filename
	_other 		unnamed arguments
	key1,..		named arguments
*/

function parse_cli_args() {
	
	if (PHP_SAPI!='cli') return false;
	
	$args=array('_cmd' => $_SERVER['argv'][0], '_other' => array() );
	
	$argn='';
	for ($i=1; $i<=$_SERVER['argc']-1; $i++) {
		if (substr($_SERVER['argv'][$i],0,1)=='-') { 
			$argn=substr($_SERVER['argv'][$i],1);
			$args[$argn]=true;
			continue; 
		}
		if ($argn!='') {
			$args[$argn]=$_SERVER['argv'][$i];
			$argn='';
		} else {
			$args['_other'][]=$_SERVER['argv'][$i];
		}
	}
	
	return $args;
}
?>